Package 'rk.janitor'

Title: An RKWard plugin package for data cleaning and validation using the 'janitor' and 'dplyr' libraries.
Description: An RKWard plugin package for data cleaning and validation using the 'janitor' and 'dplyr' libraries.
Authors: Alfonso Cano
Maintainer: Alfonso Cano <[email protected]>
License: GPL (>= 3)
Version: 0.0.2
Built: 2026-06-04 10:02:44 UTC
Source: https://github.com/AlfCano/rk.janitor

Help Index